<?php
/*
Plugin Name: #BW LESS-CSS
Plugin URI: http://support.briteweb.com/plugins/bw-less-css/
Version: 1.3.1
Description: Helper plugin to compile and include LESS CSS files. 
Author: #BRITEWEB
Author URI: http://www.briteweb.com/
*/

require_once( dirname(__FILE__).'/bw_menu.php');// Add BW top-level menu

define( 'BW_LESSCSS_SETTINGS_OPTION', 'bw_lesscss' );

register_activation_hook( __FILE__, 'bw_lesscss_activation' );
function bw_lesscss_activation() {
	$default = array( array( 'file' => 'style.less', 'active' => 1 ) );
	if ( !get_option( BW_LESSCSS_SETTINGS_OPTION ) ) update_option( BW_LESSCSS_SETTINGS_OPTION, $default );
}

add_action( 'after_setup_theme', 'bw_lesscss_include' );
function bw_lesscss_include() {
	$styles = get_option( BW_LESSCSS_SETTINGS_OPTION );
	
	if ( !empty( $styles ) )
		foreach ( $styles as $style ) {
			if ( $style['active'] == 1 ) {
				$media = ( !empty( $style['cmedia'] ) ) ? $style['cmedia'] : $style['media'];
				bw_less_css( $style['file'], $media, $style['minify'] );
			}
		}
	
}

/* ========| INCLUDE LESS CLASS |======== */
	
require_once( dirname(__FILE__).'/lessc.inc.php');

/* ========| LESS INCLUDE |======== */

function bw_less_css( $less = "", $media = "all", $minify = false ) {

	if ( !is_admin() && !empty( $less ) ) {
		$output_name =  $less . '.css';
		if ( file_exists( STYLESHEETPATH . '/' . $output_name ) && filemtime( STYLESHEETPATH . '/' . $less ) > filemtime( STYLESHEETPATH . '/' . $output_name ) ) $changed = true;
		
		try {
			lessc::ccompile( STYLESHEETPATH . '/' . $less, STYLESHEETPATH . '/' . $output_name );
		} catch ( Exception $ex ) {
			wp_die( '<strong>#BW LESS-CSS:</strong> lessc fatal error<br />' . $ex->getMessage() );
		}
		
		if ( $minify && $changed ) {
			require_once( dirname(__FILE__).'/minifycss.php');// CSS minify library
			$css = file_get_contents( STYLESHEETPATH . '/' . $output_name );
			$css = Minify_CSS_Compressor::process( $css );
			file_put_contents( STYLESHEETPATH . '/' . $output_name, $css );
		}
		
		$name = str_replace( '.', '', $less ) . "_css";
		wp_enqueue_style( $name, get_bloginfo( 'stylesheet_directory' ) . '/' . $output_name, false, false, $media );
		
	}

}

/* ========| CREATE ADMIN PAGE |======== */

add_action('admin_print_scripts', 'bw_lesscss_admin_js');
function bw_lesscss_admin_js() {
	wp_enqueue_script( 'bw_lesscss_js', plugins_url( 'bw_js.js', __FILE__ ) );
}

add_action( 'admin_menu', 'bw_lesscss_admin_menu'); // Add admin settings page for plugin
function bw_lesscss_admin_menu() {
	add_submenu_page( 'bw_plugin_menu', '#BW LESS-CSS', 'LESS-CSS', 'manage_options', 'bw-lesscss', 'bw_lesscss_admin');
}

function bw_lesscss_admin_css() {
	wp_enqueue_style( 'bw_admin_css', plugins_url( 'bw_admin.css', __FILE__ ) );
}
add_action( 'admin_print_styles', 'bw_lesscss_admin_css' );

function bw_lesscss_admin() {

	

	$fields = get_option( BW_LESSCSS_SETTINGS_OPTION );
	
	$media_types = array( 'all' => 'All', 'print' => 'Print', 'screen' => 'Screen', 'handheld' => 'Handheld' );
		
	if ( !empty( $_POST ) && $_POST['action'] == 'less_fields_save' && check_admin_referer( 'less_fields_save' ) ) {
	
		$new_fields = array();
				
		foreach ( $_POST['field_file'] as $key=>$name ) {
			if ( !empty( $name ) && strpos( $name, '.less' ) !== false ) {
				$active = ( $_POST['field_active'][$key] == 1 ) ? 1 : 0;
				$minify = ( $_POST['field_minify'][$key] == 1 ) ? true : false;
				
				$new_fields[] = array( 
					'file' => trim( $name ),
					'active' => $active,
					'media' => $_POST['field_media'][$key],
					'cmedia' => $_POST['field_cmedia'][$key],
					'minify' => $minify
				);
										
			}
		}
				
		$test = array();
		foreach ( $new_fields as $key=>$row ) $test[$key] = $row['file'];
		$unique = array_unique( $test );	
    	$new_fields = array_intersect_key( $new_fields, $unique );
    			
		update_option( BW_LESSCSS_SETTINGS_OPTION, $new_fields );
		$fields = $new_fields;
	
	}
						
	?><div class="wrap">
	
	<h2><img src="<?php echo plugins_url('/images/bw-page-logo.png', __FILE__); ?>" alt="#BW LESS-CSS" /></h2><br />
	
	<div id="info"></div>
	
	<form method="post" id="bw_lesscss_form">
	
	<table class="widefat" style="width:620px">
	<thead>
		<tr>
			<th scope="col" class="check-column">&nbsp;</th>
			<th scope="col">File</th>
			<th scope="col">Media</th>
			<th scope="col">…or Custom Media</th>
			<th scope="col">Minify</th>
			<th scope="col">Active</th>
			<th scope="col">&nbsp;</th>
		</tr>
	</thead>
	<tfoot>
		<tr>
			<th scope="col" class="check-column">&nbsp;</th>
			<th scope="col">File</th>
			<th scope="col">Media</th>
			<th scope="col">…or Custom Media</th>
			<th scope="col">Minify</th>
			<th scope="col">Active</th>
			<th scope="col">&nbsp;</th>
		</tr>
	</tfoot>
	<tbody class="field-rows">
	<?php foreach ( (array)$fields as $key=>$field ) : ?>	
		<tr class="field-row">
			<td></td>
			<td><input type="text" name="field_file[]" value="<?php echo $field['file']; ?>" /></td>
			<td><select name="field_media[]">
				<?php foreach ( $media_types as $key=>$row ) : ?>
				<option value="<?php echo $key; ?>" <?php selected( $field['media'], $key ); ?>><?php echo $row; ?></option>
				<?php endforeach; ?>
			</select></td>
			<td><input type="text" name="field_cmedia[]" value="<?php echo $field['cmedia']; ?>" /></td>
			<td><input type="checkbox" name="field_minify[]" value="1" <?php checked( $field['minify'], true ); ?> style="margin-top:7px" /></td>
			<td><input type="checkbox" name="field_active[]" value="1" <?php checked( $field['active'], 1 ); ?> style="margin-top:7px" /></td>
			<td><a href="#delete" class="bw-delete-field"><img src="<?php echo plugins_url('/images/delete.png', __FILE__); ?>" title="Delete Row" style="margin-top:5px" /></a></td>
		</tr>
	<?php endforeach; ?>
		<tr class="field-row field-template">
			<td><a href="#add" class="bw-add-field"><img src="<?php echo plugins_url('/images/add.png', __FILE__); ?>" title="Delete Row" style="margin-top:5px" /></a></td>
			<td><input type="text" name="field_file[]" value="" /></td>
			<td><select name="field_media[]">
				<?php foreach ( $media_types as $key=>$row ) : ?>
				<option value="<?php echo $key; ?>"><?php echo $row; ?></option>
				<?php endforeach; ?>
			</select></td>
			<td><input type="text" name="field_cmedia[]" value="" /></td>
			<td><input type="checkbox" name="field_minify[]" value="1" <?php checked( 1, 1 ); ?> style="margin-top:6px;" /></td>
			<td><input type="checkbox" name="field_active[]" value="1" <?php checked( 1, 1 ); ?> style="margin-top:6px;" /></td>
			<td><a href="#delete" class="bw-delete-field"><img src="<?php echo plugins_url('/images/delete.png', __FILE__); ?>" title="Delete Row" style="margin-top:5px" /></a></td>
		</tr>
	</tbody>
	</table>
	
	<p class="submit"><input type="submit" class="button-primary" value="Save Changes" /></p>
	<input type="hidden" name="action" value="less_fields_save" />
	<?php wp_nonce_field( "less_fields_save" ); ?>
	
	</form>
	
	<style type="text/css">
		#bw-dashboard-logo {
		bottom: -18px;
		display: block;
		position: absolute;
		right: -18px;
		}
	</style>
	
	<?php
	
}

/* ========| UTILITY FUNCTIONS |======== */

if ( !function_exists( 'bw_trim_value' ) ) {
function bw_trim_value( &$value ) { 
    $value = trim( $value ); 
}
}


?>